load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/wrf/WRFUserARW.ncl"

begin

fName = "fitness.log"
fName2 = "fitness"
asciiwrite(fName,"SUCCESS")
asciiwrite(fName2,"-1.")

SN = 135
WE = 115

idir = "/home/sjpark/GA/exp_sokcho/RAR/output/5km_RAR/"

fin = addfile(idir+"RAR_CAPPI_12hourly_ACCPREP_2018080512-0600_5km.nc","r")
;*****************************************************************
rar  = fin->rar
lat  = fin->lat
lon  = fin->lon

rar@_FillValue = -999.9
rar!0="south_north"
rar!1="west_east"
lat!1="west_east"
lat!0="south_north"
lon!1="west_east"
lon!0="south_north"
rar@lat2d:=lat
rar@lon2d:=lon

rar = where(ismissing(rar), 0.,rar)
;printMinMax(rar,0)
;printVarSummary(rar)

chit = new((/SN,WE/),"float")
cfal = new((/SN,WE/),"float")
cmis = new((/SN,WE/),"float")
ccor = new((/SN,WE/),"float")

chit@_FillValue = -999.9
cfal@_FillValue = -999.9
cmis@_FillValue = -999.9
ccor@_FillValue = -999.9

;;;;;; read WRF output
;*****************************************************************
; 12-hour accumulated precipitation
;
ifil  = "wrfout_d02_2018-08-06_00:00:00"
bifil = "wrfout_d02_2018-08-05_12:00:00"
;*****************************************************************
a = addfile(ifil,"r")
b = addfile(bifil,"r")

lat = wrf_user_getvar(a,"XLAT",0)      ; Latitude 
lon = wrf_user_getvar(a,"XLONG",0)     ; Longitude 
rain = wrf_user_getvar(a,"RAINC",0)     ; Accumulated total cumulus precipitation (mm)
crain = wrf_user_getvar(a,"RAINNC",0)     ; Accumulated total grid scale precipitation(mm)
brain = wrf_user_getvar(b,"RAINC",0)     ; Accumulated total cumulus precipitation (mm)
bcrain = wrf_user_getvar(b,"RAINNC",0)     ; Accumulated total grid scale precipitation(mm)
rain_plane = (rain+crain) - (brain+bcrain)
rain_plane@_FillValue = -999.9
rain_plane = where(ismissing(rain_plane), 0.,rain_plane)
;printVarSummary(rain_plane)
;printMinMax(rain_plane,0)

npt = -1
ETS = 0.
fit = new(35,"string")

npt = npt + 1
fit(npt)="time       ETS       tot_ETS      TS     Hits  False_alarms  Misses  Correct_rej    Chance" 

;;;;; events/non-events
do threshold = 3,3
  
  thrsd = int2flt(threshold)

  hit = 0.
  fal = 0.
  mis = 0.
  cor = 0.
  chance = 0.
  ETSM = 0.

  do i=0,WE-1
    do j=0,SN-1
      if(rar(j,i) .ge. thrsd .and. rain_plane(j,i) .ge. thrsd) then
    	  hit=hit+1.
      else if(rar(j,i) .lt. thrsd .and. rain_plane(j,i) .ge. thrsd) then
	  fal=fal+1.
      else if(rar(j,i) .ge. thrsd .and. rain_plane(j,i) .lt. thrsd) then
	  mis=mis+1.
      else if(rar(j,i) .lt. thrsd .and. rain_plane(j,i) .lt. thrsd) then
	  cor=cor+1.
      end if
      end if
      end if
      end if
    end do
  end do

  chance = (hit+mis)*(hit+fal)/(hit+mis+cor+fal)

  if hit+mis+fal-chance .eq. 0. then 
    print("(hit+mis+fal-chance)=0: thres="+thrsd)
    ETSM = 0.
  else
    ETSM = (hit - chance)/(hit+mis+fal-chance)
  end if
  if hit+mis+fal .eq. 0. then
    TS = -999.9
  else
    TS = hit/(hit+mis+fal)
  end if
  ETS = ETS + ETSM

  npt = npt + 1
  fit(npt) = sprintf("%5.1f",thrsd)
  fit(npt) = fit(npt)+sprintf("%12.6f",ETSM)
  fit(npt) = fit(npt)+sprintf("%12.6f",ETS)
  fit(npt) = fit(npt)+sprintf("%12.6f",TS)
  fit(npt) = fit(npt)+sprintf("%10.0f",hit)
  fit(npt) = fit(npt)+sprintf("%10.0f",mis)
  fit(npt) = fit(npt)+sprintf("%10.0f",fal)
  fit(npt) = fit(npt)+sprintf("%10.0f",cor)
  fit(npt) = fit(npt)+sprintf("%15.6f",chance)
end do

  fit(npt+1)=" SUCCESS"
  sfit = new(npt+2,"string")
  sfit = fit(0:npt+1)
  
  fName = "fitness.log"
  fName2 = "fitness"
  asciiwrite(fName,sfit)
  asciiwrite(fName2,ETS)

  delete(fit)
  delete(sfit)
  delete(fName)
  delete(fName2)

end
